:html_theme.sidebar_secondary.remove: true

.. _bibliography:

Bibliography
============

.. _[Burdet2013]:

:ref:`[Burdet2013] <[Burdet2013]>`
   P. Burdet, J. Vannod, A. Hessler-Wyser,
   M. Rappaz, and M. Cantoni, "Three-dimensional chemical analysis of
   laser-welded NiTi–stainless steel wires using a dual-beam FIB,"
   *Acta Materialia* 61 (2013): 3090–3098
   [`<https://doi.org/10.1016/j.actamat.2013.01.069>`_].

.. _Chantler2005:

:ref:`[Chantler2005] <Chantler2005>`
   C. Chantler, K. Olsen, R. Dragoset,
   J. Chang, A. Kishore, S. Kotochigova, and D. Zucker, "Detailed Tabulation
   of Atomic Form Factors, Photoelectric Absorption and Scattering Cross
   Section, and Mass Attenuation Coefficients for Z = 1-92 from E = 1-10 eV
   to E = 0.4-1.0 MeV" *NIST Standard Reference Data*
   [`<https://physics.nist.gov/ffast>`_].

.. _Egerton2011:

:ref:`[Egerton2011] <Egerton2011>`
   R. Egerton, "Electron Energy-Loss
   Spectroscopy in the Electron Microscope," Springer-Verlag, 2011
   [`<https://doi.org/10.1007/978-1-4419-9583-4>`_].

.. _MacArthur2016:

:ref:`[MacArthur2016] <MacArthur2016>`
   K. MacArthur, T. Slater, S. Haigh,
   D. Ozkaya, P. Nellist, and S. Lozano-Perez, "Quantitative Energy-Dispersive
   X-Ray Analysis of Catalyst Nanoparticles Using a Partial Cross Section
   Approach," *Microsc. Microanal.* 22 (2016): 71–81
   [`<https://doi.org/10.1017/S1431927615015494>`_].

.. _Rossouw2015:

:ref:`[Rossouw2015] <Rossouw2015>`
   D. Rossouw, P. Burdet, F. de la Peña,
   C. Ducati, B. Knappett, A. Wheatley, and P. Midgley, "Multicomponent Signal
   Unmixing from Nanoheterostructures: Overcoming the Traditional Challenges of
   Nanoscale X-ray Analysis via Machine Learning," *Nano Lett.* 15(4) (2015):
   2716–2720 [`<https://doi.org/10.1021/acs.nanolett.5b00449>`_].

.. _Watanabe1996:

:ref:`[Watanabe1996] <Watanabe1996>`
   M. Watanabe, Z. Horita, and M. Nemoto,
   "Absorption correction and thickness determination using the zeta factor in
   quantitative X-ray microanalysis," *Ultramicroscopy* 65 (1996): 187–198
   [`<https://doi.org/10.1016/S0304-3991(96)00070-8>`_].

.. _Watanabe2006:

:ref:`[Watanabe2006] <Watanabe2006>`
   M. Watanabe and D. Williams, "The
   quantitative analysis of thin specimens: a review of progress from the
   Cliff-Lorimer to the new zeta-factor methods," *J. Microsc.* 221 (2006):
   89–109 [`<https://onlinelibrary.wiley.com/doi/10.1111/j.1365-2818.2006.01549.x>`_].

.. _Williams2009:

:ref:`[Williams2009] <Williams2009>`
   D. Williams and B Carter, "Transmission
   Electron Microscopy: A Textbook for Materials Science (Part 4)," Second Ed.,
   Springer, New York, 2009
   [`<https://doi.org/10.1007/978-0-387-76501-3>`_].
